==> trade-center-api-2.2.5-20181127.081235-1-sources.jar: cn/com/duiba/order/center/api/dto/AmbPaychannelOrdersDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author yansen
 */
public class AmbPaychannelOrdersDto implements Serializable {


    public static final String PayChannelOrdersStatusWaitPay = "wait_pay";

    public static final String PayChannelOrdersStatusSuccess = "success";
    public static final String PayChannelOrdersStatusFail = "fail";
    public static final String PayChannelOrdersStatusCanceled = "canceled";


    public static final String PayChannelOrdersPayChannelTypeAlipay = "alipay";

    /**
     * 开发者收银台
     */
    public static final String PayChannelOrdersPayChannelTypeDeveloper = "developer_cashier";


    public static final String PayChannelOrdersPayChannelTypeWeixin = "weixin";

    public static final String PayChannelOrdersPayChannelTypeRefundStatus = "send";
    public static final String PayChannelOrdersPayChannelTypeRefundSuccess = "success";
    private static final long serialVersionUID = 4263221888538506990L;


    private Long id;

    private Long developerId;

    private Long appId;

    private Long ordersId;

    private Long ambSubOrdersId;

    private String status;

    private String paychannelType;

    private Integer subPaychannelType;

    private Long consumerMoney;

    private String orderNum;

    private String tradeNum;

    private Long refundPrice;

    private String refundStatus;

    private String ordersSource;

    private Date gmtCreate;

    private Date gmtModified;

    public Integer getSubPaychannelType() {
        return subPaychannelType;
    }

    public void setSubPaychannelType(Integer subPaychannelType) {
        this.subPaychannelType = subPaychannelType;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOrdersId() {
        return ordersId;
    }

    public void setOrdersId(Long ordersId) {
        this.ordersId = ordersId;
    }

    public Long getAmbSubOrdersId() {
        return ambSubOrdersId;
    }

    public void setAmbSubOrdersId(Long ambSubOrdersId) {
        this.ambSubOrdersId = ambSubOrdersId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getPaychannelType() {
        return paychannelType;
    }

    public void setPaychannelType(String paychannelType) {
        this.paychannelType = paychannelType;
    }

    public Long getConsumerMoney() {
        return consumerMoney;
    }

    public void setConsumerMoney(Long consumerMoney) {
        this.consumerMoney = consumerMoney;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getTradeNum() {
        return tradeNum;
    }

    public void setTradeNum(String tradeNum) {
        this.tradeNum = tradeNum;
    }

    public Long getRefundPrice() {
        return refundPrice;
    }

    public void setRefundPrice(Long refundPrice) {
        this.refundPrice = refundPrice;
    }

    public String getRefundStatus() {
        return refundStatus;
    }

    public void setRefundStatus(String refundStatus) {
        this.refundStatus = refundStatus;
    }

    public String getOrdersSource() {
        return ordersSource;
    }

    public void setOrdersSource(String ordersSource) {
        this.ordersSource = ordersSource;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}

==> trade-center-api-2.3.5-sources.jar: cn/com/duiba/order/center/api/dto/AmbPaychannelOrdersDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author yansen
 */
public class AmbPaychannelOrdersDto implements Serializable {


    public static final String PayChannelOrdersStatusWaitPay = "wait_pay";

    public static final String PayChannelOrdersStatusSuccess = "success";
    public static final String PayChannelOrdersStatusFail = "fail";
    public static final String PayChannelOrdersStatusCanceled = "canceled";


    public static final String PayChannelOrdersPayChannelTypeAlipay = "alipay";

    /**
     * 开发者收银台
     */
    public static final String PayChannelOrdersPayChannelTypeDeveloper = "developer_cashier";


    public static final String PayChannelOrdersPayChannelTypeWeixin = "weixin";

    public static final String PayChannelOrdersPayChannelTypeSuZhou = "SuZhou";

    /**
     * 开发者自有支付，钱不过兑吧
     */
    public static final String PayChannelOrdersPayChannelTypeSelf = "self";

    public static final String PayChannelOrdersPayChannelTypeRefundStatus = "send";
    public static final String PayChannelOrdersPayChannelTypeRefundSuccess = "success";
    public static final String PayChannelOrdersPayChannelTypeRefundFail = "fail";
    private static final long serialVersionUID = 4263221888538506990L;


    private Long id;

    private Long developerId;

    private Long appId;

    private Long ordersId;

    private Long ambSubOrdersId;

    private String status;

    private String paychannelType;

    private Integer subPaychannelType;

    private Long consumerMoney;

    private String orderNum;

    private String tradeNum;

    private Long refundPrice;

    private String refundStatus;

    private String ordersSource;

    private Date gmtCreate;

    private Date gmtModified;

    /**
     * 退款成功时间
     */
    private Date refundSucceedTime;

    public Integer getSubPaychannelType() {
        return subPaychannelType;
    }

    public void setSubPaychannelType(Integer subPaychannelType) {
        this.subPaychannelType = subPaychannelType;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOrdersId() {
        return ordersId;
    }

    public void setOrdersId(Long ordersId) {
        this.ordersId = ordersId;
    }

    public Long getAmbSubOrdersId() {
        return ambSubOrdersId;
    }

    public void setAmbSubOrdersId(Long ambSubOrdersId) {
        this.ambSubOrdersId = ambSubOrdersId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getPaychannelType() {
        return paychannelType;
    }

    public void setPaychannelType(String paychannelType) {
        this.paychannelType = paychannelType;
    }

    public Long getConsumerMoney() {
        return consumerMoney;
    }

    public void setConsumerMoney(Long consumerMoney) {
        this.consumerMoney = consumerMoney;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getTradeNum() {
        return tradeNum;
    }

    public void setTradeNum(String tradeNum) {
        this.tradeNum = tradeNum;
    }

    public Long getRefundPrice() {
        return refundPrice;
    }

    public void setRefundPrice(Long refundPrice) {
        this.refundPrice = refundPrice;
    }

    public String getRefundStatus() {
        return refundStatus;
    }

    public void setRefundStatus(String refundStatus) {
        this.refundStatus = refundStatus;
    }

    public String getOrdersSource() {
        return ordersSource;
    }

    public void setOrdersSource(String ordersSource) {
        this.ordersSource = ordersSource;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getRefundSucceedTime() {
        return refundSucceedTime;
    }

    public void setRefundSucceedTime(Date refundSucceedTime) {
        this.refundSucceedTime = refundSucceedTime;
    }
}
